@@ -1,11 +1,11 @@
-'''
-:mod:`ophyd.hkl` - HKL calculation utilities
-============================================
+"""
+:mod:`hkl` - HKL diffractometer support
+=======================================
 
-.. module:: ophyd.hkl
+.. module:: hkl
    :synopsis:
 
-'''
+"""
 
 import logging
 
@@ -13,5 +13,6 @@ logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
 
 from ._version import get_versions  # noqa: F402, E402
-__version__ = get_versions()['version']
+
+__version__ = get_versions()["version"]
 del get_versions
