@@ -8,9 +8,31 @@ import numpy as np
 from .engine import Engine, CalcParameter
 from .sample import HklSample
 from . import util
-from .util import hkl_module
+from .util import libhkl
 from .context import UsingEngine
 
+__all__ = """
+    A_KEV
+    CalcE4CH
+    CalcE4CV
+    CalcE6C
+    CalcK4CV
+    CalcK6C
+    CalcMed2p3
+    CalcPetra3_p09_eh2
+    CalcRecip
+    CalcSoleilMars
+    CalcSoleilSiriusKappa
+    CalcSoleilSiriusTurret
+    CalcSoleilSixs
+    CalcSoleilSixsMed1p2
+    CalcSoleilSixsMed2p2
+    CalcTwoC
+    CalcZaxis
+    default_decision_function
+    NM_KEV
+    UnreachableError
+""".split()
 logger = logging.getLogger(__name__)
 
 A_KEV = 12.39842  # 1 Angstrom = 12.39842 keV
@@ -120,13 +142,10 @@ class CalcRecip(object):
         self._inverted_axes = inverted_axes or []
 
         try:
-            self._factory = hkl_module.factories()[dtype]
+            self._factory = libhkl.factories()[dtype]
         except KeyError:
             types = ", ".join(util.diffractometer_types)
-            raise ValueError(
-                f"Invalid diffractometer type {repr(types)};"
-                f" choose from: {types}"
-            )
+            raise ValueError(f"Invalid diffractometer type {types!r};  choose from: {types}")
 
         self._geometry = self._factory.create_new_geometry()
         self._engine_list = self._factory.create_new_engine_list()
@@ -146,9 +165,7 @@ class CalcRecip(object):
         """Dynamically-generated physical motor position class"""
         # I know, I know, could be done more cleanly...
         name = f"Pos{self.__class__.__name__}"
-        return util.get_position_tuple(
-            self.physical_axis_names, class_name=name
-        )
+        return util.get_position_tuple(self.physical_axis_names, class_name=name)
 
     @property
     def wavelength(self):
@@ -184,12 +201,9 @@ class CalcRecip(object):
             return
 
         if self._lock_engine and self._engine is not None:
-            raise ValueError(
-                "Engine is locked on this %s instance"
-                % self.__class__.__name__
-            )
+            raise ValueError("Engine is locked on this %s instance" % self.__class__.__name__)
 
-        if isinstance(engine, hkl_module.Engine):
+        if isinstance(engine, libhkl.Engine):
             self._engine = engine
         else:
             engines = self.engines
@@ -200,15 +214,20 @@ class CalcRecip(object):
 
         self._re_init()
 
+    @property
+    def geometry_name(self):
+        """Name of this geometry, as defined in **libhkl**."""
+        return self._geometry.name_get()
+
     def _get_sample(self, name):
-        if isinstance(name, hkl_module.Sample):
+        if isinstance(name, libhkl.Sample):
             return name
 
         return self._samples[name]
 
     @property
     def sample_name(self):
-        """The name of the currently selected sample"""
+        """The name of the currently selected sample."""
         return self._sample.name
 
     @sample_name.setter
@@ -252,20 +271,14 @@ class CalcRecip(object):
         select : bool, optional
             Select the sample to focus calculations on
         """
-        if not isinstance(sample, (HklSample, hkl_module.Sample)):
-            raise ValueError(
-                "Expected either an HklSample or a Sample " "instance"
-            )
+        if not isinstance(sample, (HklSample, libhkl.Sample)):
+            raise ValueError("Expected either an HklSample or a Sample instance")
 
-        if isinstance(sample, hkl_module.Sample):
-            sample = HklSample(
-                calc=self, sample=sample, units=self._unit_name
-            )
+        if isinstance(sample, libhkl.Sample):
+            sample = HklSample(calc=self, sample=sample, units=self._unit_name)
 
         if sample.name in self._samples:
-            raise ValueError(
-                'Sample of name "%s" already exists' % sample.name
-            )
+            raise ValueError('Sample of name "%s" already exists' % sample.name)
 
         self._samples[sample.name] = sample
         if select:
@@ -287,9 +300,7 @@ class CalcRecip(object):
             Select the sample to focus calculations on
         """
         units = kwargs.pop("units", self._unit_name)
-        sample = HklSample(
-            self, sample=hkl_module.Sample.new(name), units=units, **kwargs
-        )
+        sample = HklSample(self, sample=libhkl.Sample.new(name), units=units, **kwargs)
 
         return self.add_sample(sample, select=select)
 
@@ -298,19 +309,11 @@ class CalcRecip(object):
         if self._engine is None:
             return
 
-        if (
-            self._geometry is None
-            or self._detector is None
-            or self._sample is None
-        ):
-            raise ValueError(
-                "Not all parameters set (geometry, detector, sample)"
-            )
+        if self._geometry is None or self._detector is None or self._sample is None:
+            raise ValueError("Not all parameters set (geometry, detector, sample)")
             # pass
         else:
-            self._engine_list.init(
-                self._geometry, self._detector, self._sample.hkl_sample
-            )
+            self._engine_list.init(self._geometry, self._detector, self._sample.hkl_sample)
 
     @property
     def engines(self):
@@ -345,12 +348,8 @@ class CalcRecip(object):
         if set(axis_name_map.keys()) != set(internal_axis_names):
             raise ValueError("Every axis name has to have a remapped name")
 
-        self._axis_name_to_original = OrderedDict(
-            (axis_name_map[axis], axis) for axis in internal_axis_names
-        )
-        self._axis_name_to_renamed = OrderedDict(
-            (axis, axis_name_map[axis]) for axis in internal_axis_names
-        )
+        self._axis_name_to_original = OrderedDict((axis_name_map[axis], axis) for axis in internal_axis_names)
+        self._axis_name_to_renamed = OrderedDict((axis, axis_name_map[axis]) for axis in internal_axis_names)
 
         self._inverted_axes = []
 
@@ -403,10 +402,12 @@ class CalcRecip(object):
     def physical_axes(self):
         """Physical (real) motor positions as an OrderedDict"""
         return OrderedDict(
+            # fmt: off
             zip(
                 self.physical_axis_names,
                 self._geometry.axis_values_get(self._units),
             )
+            # fmt: on
         )
 
     @property
@@ -458,9 +459,7 @@ class CalcRecip(object):
         param.value = value
 
     @_keep_physical_position
-    def forward_iter(
-        self, start, end, max_iters, *, threshold=0.99, decision_fcn=None
-    ):
+    def forward_iter(self, start, end, max_iters, *, threshold=0.99, decision_fcn=None):
         """Iteratively attempt to go from a pseudo start -> end position
 
         For every solution failure, the position is moved back.
@@ -523,9 +522,7 @@ class CalcRecip(object):
                 t = (t + 1) / 2.0
 
                 valid_pseudo = self.engine.pseudo_positions
-                valid_real = decision_fcn(
-                    valid_pseudo, self.engine.solutions
-                )
+                valid_real = decision_fcn(valid_pseudo, self.engine.solutions)
                 self.physical_positions = valid_real
 
                 if t >= threshold:
@@ -541,7 +538,7 @@ class CalcRecip(object):
                 f"Unable to solve. iterations={iters}/{max_iters}\n"
                 f"Last valid position: {valid_pseudo}\n{valid_real} ",
                 pseudo=valid_pseudo,
-                physical=valid_real
+                physical=valid_real,
             )
 
     @_keep_physical_position
@@ -566,9 +563,7 @@ class CalcRecip(object):
         # end   = [h2, k2, l2]
 
         # from start to end, in a linear path
-        singles = [
-            np.linspace(start[i], end[i], n + 1) for i in range(num_params)
-        ]
+        singles = [np.linspace(start[i], end[i], n + 1) for i in range(num_params)]
 
         return list(zip(*singles))
 
@@ -576,13 +571,9 @@ class CalcRecip(object):
         try:
             return getattr(self, "calc_%s_path" % (path_type))
         except AttributeError:
-            raise ValueError(
-                "Invalid path type specified (%s)" % path_type
-            )
+            raise ValueError("Invalid path type specified (%s)" % path_type)
 
-    def get_path(
-        self, start, end=None, n=100, path_type="linear", **kwargs
-    ):
+    def get_path(self, start, end=None, n=100, path_type="linear", **kwargs):
         num_params = len(self.pseudo_axis_names)
 
         start = np.array(start)
@@ -592,9 +583,7 @@ class CalcRecip(object):
         if end is not None:
             end = np.array(end)
             if start.size == end.size == num_params:
-                return path_fcn(
-                    start, end, n, num_params=num_params, **kwargs
-                )
+                return path_fcn(start, end, n, num_params=num_params, **kwargs)
 
         else:
             positions = np.array(start)
@@ -602,52 +591,43 @@ class CalcRecip(object):
                 # single position
                 return [list(positions)]
             elif positions.ndim == 2:
-                if (
-                    positions.shape[0] == 1
-                    and positions.size == num_params
-                ):
+                if positions.shape[0] == 1 and positions.size == num_params:
                     # [[h, k, l], ]
                     return [positions[0]]
                 elif positions.shape[0] == num_params:
                     # [[h, k, l], [h, k, l], ...]
                     return [positions[i, :] for i in range(num_params)]
 
-        raise ValueError(
-            "Invalid set of %s positions"
-            % ", ".join(self.pseudo_axis_names)
-        )
+        raise ValueError("Invalid set of %s positions" % ", ".join(self.pseudo_axis_names))
 
     def __call__(
+        # fmt: off
         self,
         start,
         end=None,
         n=100,
         engine=None,
         path_type="linear",
-        **kwargs
+        **kwargs,
+        # fmt: on
     ):
 
         with UsingEngine(self, engine):
-            for pos in self.get_path(
-                start, end=end, n=n, path_type=path_type, **kwargs
-            ):
+            for pos in self.get_path(start, end=end, n=n, path_type=path_type, **kwargs):
                 yield self.forward(pos, engine=None, **kwargs)
 
     def _repr_info(self):
         r = [
-            f"engine={repr(self.engine.name)}",
-            f"detector={repr(self._detector)}",
-            f"sample={repr(self._sample)}",
-            f"samples={repr(self._samples)}",
+            f"engine={self.engine.name!r}",
+            f"detector={self._detector!r}",
+            f"sample={self._sample!r}",
+            f"samples={self._samples!r}",
         ]
 
         return r
 
     def __repr__(self):
-        return (
-            f"{self.__class__.__name__}"
-            f"({', '.join(self._repr_info())})"
-        )
+        return f"{self.__class__.__name__} ({', '.join(self._repr_info())})"
 
     def __str__(self):
         return repr(self)
