@@ -6,32 +6,45 @@ from collections import namedtuple
 import numpy as np
 
 try:
-    from gi.repository import Hkl as hkl_module
+    from gi.repository import Hkl as libhkl
     from gi.repository import GLib
 except ImportError as ex:
-    hkl_module = None
+    libhkl = None
     GLib = None
 
-    print('[!!] Failed to import Hkl library; diffractometer support '
-          'disabled ({})'.format(ex), file=sys.stderr)
-
+    print(
+        # fmt: off
+        "[!!] Failed to import Hkl library;"
+        f" diffractometer support disabled ({ex})",
+        file=sys.stderr,
+        # fmt: on
+    )
 
+__all__ = """
+    diffractometer_types
+    get_position_tuple
+    Lattice
+    new_detector
+""".split()
 logger = logging.getLogger(__name__)
 
 
 def new_detector(dtype=0):
-    '''Create a new HKL-library detector'''
-    return hkl_module.Detector.factory_new(hkl_module.DetectorType(dtype))
+    """Create a new HKL-library detector"""
+    return libhkl.Detector.factory_new(libhkl.DetectorType(dtype))
 
 
-if hkl_module:
-    diffractometer_types = tuple(sorted(hkl_module.factories().keys()))
-    UserUnits = hkl_module.UnitEnum.USER
-    DefaultUnits = hkl_module.UnitEnum.DEFAULT
+if libhkl:
+    diffractometer_types = tuple(sorted(libhkl.factories().keys()))
+    UserUnits = libhkl.UnitEnum.USER
+    DefaultUnits = libhkl.UnitEnum.DEFAULT
 
-    units = {'user': UserUnits,
-             'default': DefaultUnits
-             }
+    # fmt: off
+    units = {
+        "user": UserUnits,
+        "default": DefaultUnits
+    }
+    # fmt: on
 else:
     diffractometer_types = ()
     units = {}
@@ -70,7 +83,7 @@ def to_hkl(arr):
     -------
     Hkl.Matrix
     """
-    if isinstance(arr, hkl_module.Matrix):
+    if isinstance(arr, libhkl.Matrix):
         return arr
 
     arr = np.array(arr)
@@ -81,9 +94,8 @@ def to_hkl(arr):
 
 
 def hkl_euler_matrix(euler_x, euler_y, euler_z):
-    """
-    """
-    return hkl_module.Matrix.new_euler(euler_x, euler_y, euler_z)
+    """ """
+    return libhkl.Matrix.new_euler(euler_x, euler_y, euler_z)
 
 
 def _gi_info(gi_val):
@@ -94,25 +106,21 @@ def _gi_info(gi_val):
             return getter()
         except Exception as ex:
             try:
-                return getter(units['user'])
+                return getter(units["user"])
             except Exception:
-                return '({}: {})'.format(ex.__class__.__name__, ex)
+                return f"({ex.__class__.__name__}: {ex})"
 
-    return {attr: get(attr)
-            for attr in dir(gi_val)
-            if attr.endswith('_get')
-            }
+    return {attr: get(attr) for attr in dir(gi_val) if attr.endswith("_get")}
 
 
-Lattice = namedtuple('LatticeTuple', 'a b c alpha beta gamma')
+Lattice = namedtuple("LatticeTuple", "a b c alpha beta gamma")
 
 
 _position_tuples = {}
 
 
-def get_position_tuple(axis_names, class_name='Position'):
-    """
-    """
+def get_position_tuple(axis_names, class_name="Position"):
+    """ """
     global _position_tuples
 
     key = frozenset(axis_names)
